@@ -1,4 +1,4 @@
-# Copyright (C) 2017-2018  The Software Heritage developers
+# Copyright (C) 2017-2020  The Software Heritage developers
 # See the AUTHORS file at the top-level directory of this distribution
 # License: GNU Affero General Public License version 3, or any later version
 # See top-level LICENSE file for more information
@@ -35,3 +35,16 @@ class YAMLRenderer(renderers.BaseRenderer):
             allow_unicode=not self.ensure_ascii,
             default_flow_style=self.default_flow_style,
         )
+
+
+class PlainTextRenderer(renderers.BaseRenderer):
+    """
+    Renderer which does not perform any serialization to raw text data.
+    """
+
+    media_type = "text/plain"
+    format = "text"
+    charset = "utf-8"
+
+    def render(self, data, media_type=None, renderer_context=None):
+        return data
