@@ -3,9 +3,10 @@
 # License: GNU Affero General Public License version 3, or any later version
 # See top-level LICENSE file for more information
 
+from typing import Any, Dict
+
 from django.http import HttpResponse
 from django.shortcuts import redirect
-from django.views.decorators.cache import never_cache
 
 from swh.model import hashutil
 from swh.web.api.apidoc import api_doc, format_docstring
@@ -41,13 +42,24 @@ def _dispatch_cook_progress(request, obj_type, obj_id):
         )
 
 
-@never_cache
+def _vault_response(vault_response: Dict[str, Any]) -> Dict[str, Any]:
+    return {
+        "fetch_url": vault_response["fetch_url"],
+        "obj_type": vault_response["type"],
+        "progress_message": vault_response["progress_msg"],
+        "id": vault_response["task_id"],
+        "status": vault_response["task_status"],
+        "obj_id": vault_response["object_id"],
+    }
+
+
 @api_route(
     r"/vault/directory/(?P<dir_id>[0-9a-f]+)/",
     "api-1-vault-cook-directory",
     methods=["GET", "POST"],
     checksum_args=["dir_id"],
     throttle_scope="swh_vault_cooking",
+    never_cache=True,
 )
 @api_doc("/vault/directory/")
 @format_docstring()
@@ -101,9 +113,9 @@ def api_vault_cook_directory(request, dir_id):
 
     res = _dispatch_cook_progress(request, "directory", obj_id)
     res["fetch_url"] = reverse(
-        "api-1-vault-fetch-directory", url_args={"dir_id": dir_id}
+        "api-1-vault-fetch-directory", url_args={"dir_id": dir_id}, request=request,
     )
-    return res
+    return _vault_response(res)
 
 
 @api_route(
@@ -147,13 +159,13 @@ def api_vault_fetch_directory(request, dir_id):
     return response
 
 
-@never_cache
 @api_route(
     r"/vault/revision/(?P<rev_id>[0-9a-f]+)/gitfast/",
     "api-1-vault-cook-revision_gitfast",
     methods=["GET", "POST"],
     checksum_args=["rev_id"],
     throttle_scope="swh_vault_cooking",
+    never_cache=True,
 )
 @api_doc("/vault/revision/gitfast/")
 @format_docstring()
@@ -208,9 +220,11 @@ def api_vault_cook_revision_gitfast(request, rev_id):
 
     res = _dispatch_cook_progress(request, "revision_gitfast", obj_id)
     res["fetch_url"] = reverse(
-        "api-1-vault-fetch-revision_gitfast", url_args={"rev_id": rev_id}
+        "api-1-vault-fetch-revision_gitfast",
+        url_args={"rev_id": rev_id},
+        request=request,
     )
-    return res
+    return _vault_response(res)
 
 
 @api_route(
