@@ -8,8 +8,6 @@ from typing import Any, Dict, cast
 import uuid
 
 from cryptography.fernet import InvalidToken
-from keycloak.exceptions import KeycloakError
-import sentry_sdk
 
 from django.conf.urls import url
 from django.contrib.auth import authenticate, login, logout
@@ -21,7 +19,6 @@ from django.http.response import (
     HttpResponse,
     HttpResponseForbidden,
     HttpResponseRedirect,
-    HttpResponseServerError,
     JsonResponse,
 )
 from django.shortcuts import render
@@ -34,17 +31,14 @@ from swh.web.auth.utils import (
     gen_oidc_pkce_codes,
     get_oidc_client,
 )
-from swh.web.common.exc import BadInputExc
+from swh.web.common.exc import BadInputExc, ForbiddenExc
 from swh.web.common.utils import reverse
+from swh.web.config import get_config
 
 
-def oidc_login(request: HttpRequest) -> HttpResponse:
-    """
-    Django view to initiate login process using OpenID Connect.
-    """
+def _oidc_login(request: HttpRequest, redirect_uri: str, scope: str = "openid"):
     # generate a CSRF token
     state = str(uuid.uuid4())
-    redirect_uri = reverse("oidc-login-complete", request=request)
 
     code_verifier, code_challenge = gen_oidc_pkce_codes()
 
@@ -60,7 +54,7 @@ def oidc_login(request: HttpRequest) -> HttpResponse:
         "state": state,
         "code_challenge": code_challenge,
         "code_challenge_method": "S256",
-        "scope": "openid",
+        "scope": scope,
         "prompt": request.GET.get("prompt", ""),
     }
 
@@ -72,26 +66,24 @@ def oidc_login(request: HttpRequest) -> HttpResponse:
     return HttpResponseRedirect(authorization_url)
 
 
-def oidc_login_complete(request: HttpRequest) -> HttpResponse:
+def oidc_login(request: HttpRequest) -> HttpResponse:
     """
-    Django view to finalize login process using OpenID Connect.
+    Django view to initiate login process using OpenID Connect.
     """
+
+    redirect_uri = reverse("oidc-login-complete", request=request)
+
+    return _oidc_login(request, redirect_uri=redirect_uri)
+
+
+def _get_login_data(request: HttpRequest) -> Dict[str, Any]:
     if "login_data" not in request.session:
         raise Exception("Login process has not been initialized.")
 
-    login_data = request.session["login_data"]
-    next_path = login_data["next_path"] or request.build_absolute_uri("/")
+    return request.session["login_data"]
 
-    if "error" in request.GET:
-        if login_data["prompt"] == "none":
-            # Silent login failed because OIDC session expired.
-            # Redirect to logout page and inform user.
-            logout(request)
-            logout_url = reverse(
-                "logout", query_params={"next_path": next_path, "remote_user": 1}
-            )
-            return HttpResponseRedirect(logout_url)
-        return HttpResponseServerError(request.GET["error"])
+
+def _check_login_data(request: HttpRequest, login_data: Dict[str, Any]):
 
     if "code" not in request.GET or "state" not in request.GET:
         raise BadInputExc("Missing query parameters for authentication.")
@@ -102,6 +94,26 @@ def oidc_login_complete(request: HttpRequest) -> HttpResponse:
     if state != login_data["state"]:
         raise BadInputExc("Wrong CSRF token, aborting login process.")
 
+
+def oidc_login_complete(request: HttpRequest) -> HttpResponse:
+    """
+    Django view to finalize login process using OpenID Connect.
+    """
+    login_data = _get_login_data(request)
+    next_path = login_data["next_path"] or request.build_absolute_uri("/")
+    if "error" in request.GET and login_data["prompt"] == "none":
+        # Silent login failed because OIDC session expired.
+        # Redirect to logout page and inform user.
+        logout(request)
+        logout_url = reverse(
+            "logout", query_params={"next_path": next_path, "remote_user": 1}
+        )
+        return HttpResponseRedirect(logout_url)
+    elif "error" in request.GET:
+        raise Exception(request.GET["error"])
+
+    _check_login_data(request, login_data)
+
     user = authenticate(
         request=request,
         code=request.GET["code"],
@@ -136,25 +148,38 @@ def oidc_logout(request: HttpRequest) -> HttpResponse:
     return HttpResponseRedirect(request.build_absolute_uri(logout_url))
 
 
-@require_http_methods(["POST"])
 def oidc_generate_bearer_token(request: HttpRequest) -> HttpResponse:
     if not request.user.is_authenticated or not isinstance(request.user, OIDCUser):
         return HttpResponseForbidden()
-    try:
-        data = json.loads(request.body.decode("utf-8"))
-        user = cast(OIDCUser, request.user)
-        oidc_client = get_oidc_client()
-        token = oidc_client.offline_token(user.username, data["password"])
-        password = data["password"].encode()
-        salt = user.sub.encode()
-        encrypted_token = encrypt_data(token.encode(), password, salt)
-        OIDCUserOfflineTokens.objects.create(
-            user_id=str(user.id), offline_token=encrypted_token
-        ).save()
-        return HttpResponse(token, content_type="text/plain")
-    except KeycloakError as e:
-        sentry_sdk.capture_exception(e)
-        return HttpResponse(status=e.response_code or 500)
+    redirect_uri = reverse("oidc-generate-bearer-token-complete", request=request)
+    return _oidc_login(
+        request, redirect_uri=redirect_uri, scope="openid offline_access"
+    )
+
+
+def oidc_generate_bearer_token_complete(request: HttpRequest) -> HttpResponse:
+    if not request.user.is_authenticated or not isinstance(request.user, OIDCUser):
+        raise ForbiddenExc("You are not allowed to generate bearer tokens.")
+    if "error" in request.GET:
+        raise Exception(request.GET["error"])
+
+    oidc_client = get_oidc_client()
+    login_data = _get_login_data(request)
+    _check_login_data(request, login_data)
+    oidc_profile = oidc_client.authorization_code(
+        code=request.GET["code"],
+        code_verifier=login_data["code_verifier"],
+        redirect_uri=login_data["redirect_uri"],
+    )
+    user = cast(OIDCUser, request.user)
+    token = oidc_profile["refresh_token"]
+    secret = get_config()["secret_key"].encode()
+    salt = user.sub.encode()
+    encrypted_token = encrypt_data(token.encode(), secret, salt)
+    OIDCUserOfflineTokens.objects.create(
+        user_id=str(user.id), offline_token=encrypted_token
+    ).save()
+    return HttpResponseRedirect(reverse("oidc-profile") + "#tokens")
 
 
 def oidc_list_bearer_tokens(request: HttpRequest) -> HttpResponse:
@@ -187,12 +212,12 @@ def oidc_get_bearer_token(request: HttpRequest) -> HttpResponse:
     if not request.user.is_authenticated or not isinstance(request.user, OIDCUser):
         return HttpResponseForbidden()
     try:
-        data = json.loads(request.body.decode("utf-8"))
+        data = json.loads(request.body.decode("ascii"))
         user = cast(OIDCUser, request.user)
         token_data = OIDCUserOfflineTokens.objects.get(id=data["token_id"])
-        password = data["password"].encode()
+        secret = get_config()["secret_key"].encode()
         salt = user.sub.encode()
-        decrypted_token = decrypt_data(token_data.offline_token, password, salt)
+        decrypted_token = decrypt_data(token_data.offline_token, secret, salt)
         return HttpResponse(decrypted_token.decode("ascii"), content_type="text/plain")
     except InvalidToken:
         return HttpResponse(status=401)
@@ -203,13 +228,13 @@ def oidc_revoke_bearer_tokens(request: HttpRequest) -> HttpResponse:
     if not request.user.is_authenticated or not isinstance(request.user, OIDCUser):
         return HttpResponseForbidden()
     try:
-        data = json.loads(request.body.decode("utf-8"))
+        data = json.loads(request.body.decode("ascii"))
         user = cast(OIDCUser, request.user)
         for token_id in data["token_ids"]:
             token_data = OIDCUserOfflineTokens.objects.get(id=token_id)
-            password = data["password"].encode()
+            secret = get_config()["secret_key"].encode()
             salt = user.sub.encode()
-            decrypted_token = decrypt_data(token_data.offline_token, password, salt)
+            decrypted_token = decrypt_data(token_data.offline_token, secret, salt)
             oidc_client = get_oidc_client()
             oidc_client.logout(decrypted_token.decode("ascii"))
             token_data.delete()
@@ -232,6 +257,11 @@ urlpatterns = [
         oidc_generate_bearer_token,
         name="oidc-generate-bearer-token",
     ),
+    url(
+        r"^oidc/generate-bearer-token-complete/$",
+        oidc_generate_bearer_token_complete,
+        name="oidc-generate-bearer-token-complete",
+    ),
     url(
         r"^oidc/list-bearer-token/$",
         oidc_list_bearer_tokens,
