@@ -8,6 +8,7 @@ import itertools
 import os
 import re
 from typing import Any, Dict, Iterable, Iterator, List, Optional, Set, Tuple, Union
+from urllib.parse import urlparse
 
 from swh.model import hashutil
 from swh.model.identifiers import CONTENT, DIRECTORY, RELEASE, REVISION, SNAPSHOT
@@ -248,6 +249,22 @@ def lookup_origin(origin: OriginInfo) -> OriginInfo:
         # slash while the url in storage have it (e.g. Debian source package)
         else:
             origin_urls.append(f"{origin['url']}/")
+        try:
+            # handle case where the "://" character sequence was mangled into ":/"
+            parsed_url = urlparse(origin["url"])
+            if (
+                parsed_url.scheme
+                and not parsed_url.netloc
+                and origin["url"].startswith(f"{parsed_url.scheme}:/")
+                and not origin["url"].startswith(f"{parsed_url.scheme}://")
+            ):
+                origin_urls.append(
+                    origin["url"].replace(
+                        f"{parsed_url.scheme}:/", f"{parsed_url.scheme}://"
+                    )
+                )
+        except Exception:
+            pass
     origins = [o for o in storage.origin_get(origin_urls) if o is not None]
     if not origins:
         msg = "Origin with url %s not found!" % origin["url"]
@@ -418,15 +435,18 @@ def lookup_directory(sha1_git):
     return map(converters.from_directory_entry, directory_entries)
 
 
-def lookup_directory_with_path(sha1_git, path_string):
-    """Return directory information for entry with path path_string w.r.t.
-    root directory pointed by directory_sha1_git
+def lookup_directory_with_path(sha1_git: str, path: str) -> Dict[str, Any]:
+    """Return directory information for entry with specified path w.r.t.
+    root directory pointed by sha1_git
 
     Args:
-        - directory_sha1_git: sha1_git corresponding to the directory
-        to which we append paths to (hopefully) find the entry
-        - the relative path to the entry starting from the directory pointed by
-        directory_sha1_git
+        sha1_git: sha1_git corresponding to the directory to which we
+            append paths to (hopefully) find the entry
+        path: the relative path to the entry starting from the root
+            directory pointed by sha1_git
+
+    Returns:
+        Directory entry information as dict.
 
     Raises:
         NotFoundExc if the directory entry is not found
@@ -435,14 +455,14 @@ def lookup_directory_with_path(sha1_git, path_string):
 
     _check_directory_exists(sha1_git, sha1_git_bin)
 
-    paths = path_string.strip(os.path.sep).split(os.path.sep)
+    paths = path.strip(os.path.sep).split(os.path.sep)
     queried_dir = storage.directory_entry_get_by_path(
-        sha1_git_bin, list(map(lambda p: p.encode("utf-8"), paths))
+        sha1_git_bin, [p.encode("utf-8") for p in paths]
     )
 
     if not queried_dir:
         raise NotFoundExc(
-            ("Directory entry with path %s from %s not found") % (path_string, sha1_git)
+            f"Directory entry with path {path} from root directory {sha1_git} not found"
         )
 
     return converters.from_directory_entry(queried_dir)
