@@ -50,7 +50,7 @@ SAVE_REQUEST_STATUS = [
 SAVE_TASK_NOT_CREATED = "not created"
 SAVE_TASK_NOT_YET_SCHEDULED = "not yet scheduled"
 SAVE_TASK_SCHEDULED = "scheduled"
-SAVE_TASK_SUCCEED = "succeed"
+SAVE_TASK_SUCCEEDED = "succeeded"
 SAVE_TASK_FAILED = "failed"
 SAVE_TASK_RUNNING = "running"
 
@@ -58,7 +58,7 @@ SAVE_TASK_STATUS = [
     (SAVE_TASK_NOT_CREATED, SAVE_TASK_NOT_CREATED),
     (SAVE_TASK_NOT_YET_SCHEDULED, SAVE_TASK_NOT_YET_SCHEDULED),
     (SAVE_TASK_SCHEDULED, SAVE_TASK_SCHEDULED),
-    (SAVE_TASK_SUCCEED, SAVE_TASK_SUCCEED),
+    (SAVE_TASK_SUCCEEDED, SAVE_TASK_SUCCEEDED),
     (SAVE_TASK_FAILED, SAVE_TASK_FAILED),
     (SAVE_TASK_RUNNING, SAVE_TASK_RUNNING),
 ]
