@@ -4,43 +4,40 @@
 # See top-level LICENSE file for more information
 
 from bisect import bisect_right
-from datetime import datetime, timezone, timedelta
+from datetime import datetime, timedelta, timezone
 from itertools import product
 import json
 import logging
 from typing import Any, Dict
 
-from django.core.exceptions import ObjectDoesNotExist
-from django.core.exceptions import ValidationError
-from django.core.validators import URLValidator
-from django.utils.html import escape
-
 from prometheus_client import Gauge
-
 import requests
 import sentry_sdk
 
-from swh.web import config
-from swh.web.common import service
-from swh.web.common.exc import BadInputExc, ForbiddenExc, NotFoundExc
-from swh.web.common.models import (
-    SaveUnauthorizedOrigin,
-    SaveAuthorizedOrigin,
-    SaveOriginRequest,
-    SAVE_REQUEST_ACCEPTED,
-    SAVE_REQUEST_REJECTED,
-    SAVE_REQUEST_PENDING,
-    SAVE_TASK_NOT_YET_SCHEDULED,
-    SAVE_TASK_SCHEDULED,
-    SAVE_TASK_SUCCEED,
-    SAVE_TASK_FAILED,
-    SAVE_TASK_RUNNING,
-    SAVE_TASK_NOT_CREATED,
-)
-from swh.web.common.origin_visits import get_origin_visits
-from swh.web.common.utils import parse_timestamp, SWH_WEB_METRICS_REGISTRY
+from django.core.exceptions import ObjectDoesNotExist, ValidationError
+from django.core.validators import URLValidator
+from django.utils.html import escape
 
 from swh.scheduler.utils import create_oneshot_task_dict
+from swh.web import config
+from swh.web.common import archive
+from swh.web.common.exc import BadInputExc, ForbiddenExc, NotFoundExc
+from swh.web.common.models import (
+    SAVE_REQUEST_ACCEPTED,
+    SAVE_REQUEST_PENDING,
+    SAVE_REQUEST_REJECTED,
+    SAVE_TASK_FAILED,
+    SAVE_TASK_NOT_CREATED,
+    SAVE_TASK_NOT_YET_SCHEDULED,
+    SAVE_TASK_RUNNING,
+    SAVE_TASK_SCHEDULED,
+    SAVE_TASK_SUCCEEDED,
+    SaveAuthorizedOrigin,
+    SaveOriginRequest,
+    SaveUnauthorizedOrigin,
+)
+from swh.web.common.origin_visits import get_origin_visits
+from swh.web.common.utils import SWH_WEB_METRICS_REGISTRY, parse_iso8601_date_to_utc
 
 scheduler = config.scheduler()
 
@@ -109,10 +106,21 @@ _visit_type_task = {"git": "load-git", "hg": "load-hg", "svn": "load-svn"}
 _save_task_status = {
     "next_run_not_scheduled": SAVE_TASK_NOT_YET_SCHEDULED,
     "next_run_scheduled": SAVE_TASK_SCHEDULED,
-    "completed": SAVE_TASK_SUCCEED,
+    "completed": SAVE_TASK_SUCCEEDED,
     "disabled": SAVE_TASK_FAILED,
 }
 
+# map scheduler task_run status to origin save status
+_save_task_run_status = {
+    "scheduled": SAVE_TASK_SCHEDULED,
+    "started": SAVE_TASK_RUNNING,
+    "eventful": SAVE_TASK_SUCCEEDED,
+    "uneventful": SAVE_TASK_SUCCEEDED,
+    "failed": SAVE_TASK_FAILED,
+    "permfailed": SAVE_TASK_FAILED,
+    "lost": SAVE_TASK_FAILED,
+}
+
 
 def get_savable_visit_types():
     return sorted(list(_visit_type_task.keys()))
@@ -157,14 +165,14 @@ def _get_visit_info_for_save_request(save_request):
     if time_delta.days <= 30:
         try:
             origin = {"url": save_request.origin_url}
-            origin_info = service.lookup_origin(origin)
+            origin_info = archive.lookup_origin(origin)
             origin_visits = get_origin_visits(origin_info)
-            visit_dates = [parse_timestamp(v["date"]) for v in origin_visits]
+            visit_dates = [parse_iso8601_date_to_utc(v["date"]) for v in origin_visits]
             i = bisect_right(visit_dates, save_request.request_date)
             if i != len(visit_dates):
                 visit_date = visit_dates[i]
                 visit_status = origin_visits[i]["status"]
-                if origin_visits[i]["status"] == "ongoing":
+                if origin_visits[i]["status"] not in ("full", "partial"):
                     visit_date = None
         except Exception as exc:
             sentry_sdk.capture_exception(exc)
@@ -176,8 +184,8 @@ def _check_visit_update_status(save_request, save_task_status):
     save_request.visit_date = visit_date
     # visit has been performed, mark the saving task as succeed
     if visit_date and visit_status is not None:
-        save_task_status = SAVE_TASK_SUCCEED
-    elif visit_status == "ongoing":
+        save_task_status = SAVE_TASK_SUCCEEDED
+    elif visit_status in ("created", "ongoing"):
         save_task_status = SAVE_TASK_RUNNING
     else:
         time_now = datetime.now(tz=timezone.utc)
@@ -189,17 +197,22 @@ def _check_visit_update_status(save_request, save_task_status):
     return visit_date, save_task_status
 
 
-def _save_request_dict(save_request, task=None):
+def _save_request_dict(save_request, task=None, task_run=None):
     must_save = False
     visit_date = save_request.visit_date
     # save task still in scheduler db
     if task:
         save_task_status = _save_task_status[task["status"]]
+        if task_run:
+            save_task_status = _save_task_run_status[task_run["status"]]
         # Consider request from which a visit date has already been found
         # as succeeded to avoid retrieving it again
         if save_task_status == SAVE_TASK_SCHEDULED and visit_date:
-            save_task_status = SAVE_TASK_SUCCEED
-        if save_task_status in (SAVE_TASK_FAILED, SAVE_TASK_SUCCEED) and not visit_date:
+            save_task_status = SAVE_TASK_SUCCEEDED
+        if (
+            save_task_status in (SAVE_TASK_FAILED, SAVE_TASK_SUCCEEDED)
+            and not visit_date
+        ):
             visit_date, _ = _get_visit_info_for_save_request(save_request)
             save_request.visit_date = visit_date
             must_save = True
@@ -313,10 +326,16 @@ def create_save_origin_request(visit_type, origin_url):
                 # get the scheduler task and its status
                 tasks = scheduler.get_tasks([sor.loading_task_id])
                 task = tasks[0] if tasks else None
-                task_status = _save_request_dict(sor, task)["save_task_status"]
+                task_runs = scheduler.get_task_runs([sor.loading_task_id])
+                task_run = task_runs[0] if task_runs else None
+                save_request = _save_request_dict(sor, task, task_run)
+                task_status = save_request["save_task_status"]
                 # create a new scheduler task only if the previous one has been
                 # already executed
-                if task_status == SAVE_TASK_FAILED or task_status == SAVE_TASK_SUCCEED:
+                if (
+                    task_status == SAVE_TASK_FAILED
+                    or task_status == SAVE_TASK_SUCCEEDED
+                ):
                     can_create_task = True
                     sor = None
                 else:
@@ -389,8 +408,12 @@ def get_save_origin_requests_from_queryset(requests_queryset):
     if task_ids:
         tasks = scheduler.get_tasks(task_ids)
         tasks = {task["id"]: task for task in tasks}
+        task_runs = scheduler.get_task_runs(tasks)
+        task_runs = {task_run["task"]: task_run for task_run in task_runs}
         for sor in requests_queryset:
-            sr_dict = _save_request_dict(sor, tasks.get(sor.loading_task_id))
+            sr_dict = _save_request_dict(
+                sor, tasks.get(sor.loading_task_id), task_runs.get(sor.loading_task_id)
+            )
             save_requests.append(sr_dict)
     return save_requests
 
@@ -592,7 +615,7 @@ def compute_save_requests_metrics():
         SAVE_TASK_NOT_CREATED,
         SAVE_TASK_NOT_YET_SCHEDULED,
         SAVE_TASK_SCHEDULED,
-        SAVE_TASK_SUCCEED,
+        SAVE_TASK_SUCCEEDED,
         SAVE_TASK_FAILED,
         SAVE_TASK_RUNNING,
     )
