@@ -3,26 +3,26 @@
 # License: GNU Affero General Public License version 3, or any later version
 # See top-level LICENSE file for more information
 
+from datetime import datetime, timedelta
+
 import pytest
 
-from datetime import datetime, timedelta
 from django.utils import timezone
 
-from swh.web.common.utils import reverse
 from swh.web.common.models import (
-    SaveUnauthorizedOrigin,
-    SaveOriginRequest,
     SAVE_REQUEST_ACCEPTED,
-    SAVE_REQUEST_REJECTED,
     SAVE_REQUEST_PENDING,
-)
-from swh.web.common.models import (
+    SAVE_REQUEST_REJECTED,
+    SAVE_TASK_FAILED,
     SAVE_TASK_NOT_CREATED,
     SAVE_TASK_NOT_YET_SCHEDULED,
     SAVE_TASK_SCHEDULED,
-    SAVE_TASK_FAILED,
-    SAVE_TASK_SUCCEED,
+    SAVE_TASK_SUCCEEDED,
+    SaveOriginRequest,
+    SaveUnauthorizedOrigin,
 )
+from swh.web.common.utils import reverse
+from swh.web.tests.utils import check_api_get_responses, check_api_post_responses
 
 pytestmark = pytest.mark.django_db
 
@@ -41,32 +41,29 @@ def test_invalid_visit_type(api_client):
             "origin_url": "https://github.com/torvalds/linux",
         },
     )
-
-    response = api_client.post(url)
-    assert response.status_code == 400
+    check_api_get_responses(api_client, url, status_code=400)
 
 
 def test_invalid_origin_url(api_client):
     url = reverse(
         "api-1-save-origin", url_args={"visit_type": "git", "origin_url": "bar"}
     )
-
-    response = api_client.post(url)
-    assert response.status_code == 400
+    check_api_get_responses(api_client, url, status_code=400)
 
 
 def check_created_save_request_status(
     api_client,
     mocker,
     origin_url,
-    scheduler_task_status,
     expected_request_status,
+    scheduler_task_status=None,
+    scheduler_task_run_status=None,
     expected_task_status=None,
     visit_date=None,
 ):
 
     mock_scheduler = mocker.patch("swh.web.common.origin_save.scheduler")
-    if not scheduler_task_status:
+    if scheduler_task_status is None:
         mock_scheduler.get_tasks.return_value = []
     else:
         mock_scheduler.get_tasks.return_value = [
@@ -80,6 +77,22 @@ def check_created_save_request_status(
             }
         ]
 
+    if scheduler_task_run_status is None:
+        mock_scheduler.get_task_runs.return_value = []
+    else:
+        mock_scheduler.get_task_runs.return_value = [
+            {
+                "backend_id": "f00c712c-e820-41ce-a07c-9bf8df914205",
+                "ended": datetime.now(tz=timezone.utc) + timedelta(minutes=5),
+                "id": 1,
+                "metadata": {},
+                "scheduled": datetime.now(tz=timezone.utc),
+                "started": None,
+                "status": scheduler_task_run_status,
+                "task": 1,
+            }
+        ]
+
     mock_scheduler.create_tasks.return_value = [
         {
             "priority": "high",
@@ -99,14 +112,13 @@ def check_created_save_request_status(
         ("swh.web.common.origin_save." "_get_visit_info_for_save_request")
     )
     mock_visit_date.return_value = (visit_date, None)
-    response = api_client.post(url)
 
     if expected_request_status != SAVE_REQUEST_REJECTED:
-        assert response.status_code == 200, response.data
+        response = check_api_post_responses(api_client, url, data=None, status_code=200)
         assert response.data["save_request_status"] == expected_request_status
         assert response.data["save_task_status"] == expected_task_status
     else:
-        assert response.status_code == 403, response.data
+        check_api_post_responses(api_client, url, data=None, status_code=403)
 
 
 def check_save_request_status(
@@ -116,6 +128,7 @@ def check_save_request_status(
     expected_request_status,
     expected_task_status,
     scheduler_task_status="next_run_not_scheduled",
+    scheduler_task_run_status=None,
     visit_date=None,
 ):
     mock_scheduler = mocker.patch("swh.web.common.origin_save.scheduler")
@@ -130,6 +143,22 @@ def check_save_request_status(
         }
     ]
 
+    if scheduler_task_run_status is None:
+        mock_scheduler.get_task_runs.return_value = []
+    else:
+        mock_scheduler.get_task_runs.return_value = [
+            {
+                "backend_id": "f00c712c-e820-41ce-a07c-9bf8df914205",
+                "ended": datetime.now(tz=timezone.utc) + timedelta(minutes=5),
+                "id": 1,
+                "metadata": {},
+                "scheduled": datetime.now(tz=timezone.utc),
+                "started": None,
+                "status": scheduler_task_run_status,
+                "task": 1,
+            }
+        ]
+
     url = reverse(
         "api-1-save-origin", url_args={"visit_type": "git", "origin_url": origin_url}
     )
@@ -138,8 +167,7 @@ def check_save_request_status(
         ("swh.web.common.origin_save." "_get_visit_info_for_save_request")
     )
     mock_visit_date.return_value = (visit_date, None)
-    response = api_client.get(url)
-    assert response.status_code == 200, response.data
+    response = check_api_get_responses(api_client, url, status_code=200)
     save_request_data = response.data[0]
 
     assert save_request_data["save_request_status"] == expected_request_status
@@ -148,8 +176,7 @@ def check_save_request_status(
     # Check that save task status is still available when
     # the scheduler task has been archived
     mock_scheduler.get_tasks.return_value = []
-    response = api_client.get(url)
-    assert response.status_code == 200
+    response = check_api_get_responses(api_client, url, status_code=200)
     save_request_data = response.data[0]
     assert save_request_data["save_task_status"] == expected_task_status
 
@@ -157,10 +184,14 @@ def check_save_request_status(
 def test_save_request_rejected(api_client, mocker):
     origin_url = "https://github.com/user/illegal_repo"
     check_created_save_request_status(
-        api_client, mocker, origin_url, None, SAVE_REQUEST_REJECTED
+        api_client, mocker, origin_url, expected_request_status=SAVE_REQUEST_REJECTED,
     )
     check_save_request_status(
-        api_client, mocker, origin_url, SAVE_REQUEST_REJECTED, SAVE_TASK_NOT_CREATED
+        api_client,
+        mocker,
+        origin_url,
+        expected_request_status=SAVE_REQUEST_REJECTED,
+        expected_task_status=SAVE_TASK_NOT_CREATED,
     )
 
 
@@ -170,12 +201,15 @@ def test_save_request_pending(api_client, mocker):
         api_client,
         mocker,
         origin_url,
-        None,
-        SAVE_REQUEST_PENDING,
-        SAVE_TASK_NOT_CREATED,
+        expected_request_status=SAVE_REQUEST_PENDING,
+        expected_task_status=SAVE_TASK_NOT_CREATED,
     )
     check_save_request_status(
-        api_client, mocker, origin_url, SAVE_REQUEST_PENDING, SAVE_TASK_NOT_CREATED
+        api_client,
+        mocker,
+        origin_url,
+        expected_request_status=SAVE_REQUEST_PENDING,
+        expected_task_status=SAVE_TASK_NOT_CREATED,
     )
 
 
@@ -185,25 +219,26 @@ def test_save_request_succeed(api_client, mocker):
         api_client,
         mocker,
         origin_url,
-        None,
-        SAVE_REQUEST_ACCEPTED,
-        SAVE_TASK_NOT_YET_SCHEDULED,
+        expected_request_status=SAVE_REQUEST_ACCEPTED,
+        expected_task_status=SAVE_TASK_NOT_YET_SCHEDULED,
     )
     check_save_request_status(
         api_client,
         mocker,
         origin_url,
-        SAVE_REQUEST_ACCEPTED,
-        SAVE_TASK_SCHEDULED,
+        expected_request_status=SAVE_REQUEST_ACCEPTED,
+        expected_task_status=SAVE_TASK_SCHEDULED,
         scheduler_task_status="next_run_scheduled",
+        scheduler_task_run_status="scheduled",
     )
     check_save_request_status(
         api_client,
         mocker,
         origin_url,
-        SAVE_REQUEST_ACCEPTED,
-        SAVE_TASK_SUCCEED,
+        expected_request_status=SAVE_REQUEST_ACCEPTED,
+        expected_task_status=SAVE_TASK_SUCCEEDED,
         scheduler_task_status="completed",
+        scheduler_task_run_status="eventful",
         visit_date=None,
     )
     visit_date = datetime.now(tz=timezone.utc) + timedelta(hours=1)
@@ -211,9 +246,10 @@ def test_save_request_succeed(api_client, mocker):
         api_client,
         mocker,
         origin_url,
-        SAVE_REQUEST_ACCEPTED,
-        SAVE_TASK_SUCCEED,
+        expected_request_status=SAVE_REQUEST_ACCEPTED,
+        expected_task_status=SAVE_TASK_SUCCEEDED,
         scheduler_task_status="completed",
+        scheduler_task_run_status="eventful",
         visit_date=visit_date,
     )
 
@@ -224,25 +260,26 @@ def test_save_request_failed(api_client, mocker):
         api_client,
         mocker,
         origin_url,
-        None,
-        SAVE_REQUEST_ACCEPTED,
-        SAVE_TASK_NOT_YET_SCHEDULED,
+        expected_request_status=SAVE_REQUEST_ACCEPTED,
+        expected_task_status=SAVE_TASK_NOT_YET_SCHEDULED,
     )
     check_save_request_status(
         api_client,
         mocker,
         origin_url,
-        SAVE_REQUEST_ACCEPTED,
-        SAVE_TASK_SCHEDULED,
+        expected_request_status=SAVE_REQUEST_ACCEPTED,
+        expected_task_status=SAVE_TASK_SCHEDULED,
         scheduler_task_status="next_run_scheduled",
+        scheduler_task_run_status="scheduled",
     )
     check_save_request_status(
         api_client,
         mocker,
         origin_url,
-        SAVE_REQUEST_ACCEPTED,
-        SAVE_TASK_FAILED,
+        expected_request_status=SAVE_REQUEST_ACCEPTED,
+        expected_task_status=SAVE_TASK_FAILED,
         scheduler_task_status="disabled",
+        scheduler_task_run_status="failed",
     )
 
 
@@ -259,9 +296,9 @@ def test_create_save_request_only_when_needed(api_client, mocker):
         api_client,
         mocker,
         origin_url,
-        "next_run_not_scheduled",
-        SAVE_REQUEST_ACCEPTED,
-        SAVE_TASK_NOT_YET_SCHEDULED,
+        scheduler_task_status="next_run_not_scheduled",
+        expected_request_status=SAVE_REQUEST_ACCEPTED,
+        expected_task_status=SAVE_TASK_NOT_YET_SCHEDULED,
     )
 
     sors = list(
@@ -273,9 +310,10 @@ def test_create_save_request_only_when_needed(api_client, mocker):
         api_client,
         mocker,
         origin_url,
-        "next_run_scheduled",
-        SAVE_REQUEST_ACCEPTED,
-        SAVE_TASK_SCHEDULED,
+        scheduler_task_status="next_run_scheduled",
+        scheduler_task_run_status="scheduled",
+        expected_request_status=SAVE_REQUEST_ACCEPTED,
+        expected_task_status=SAVE_TASK_SCHEDULED,
     )
     sors = list(
         SaveOriginRequest.objects.filter(visit_type="git", origin_url=origin_url)
@@ -287,28 +325,29 @@ def test_create_save_request_only_when_needed(api_client, mocker):
         api_client,
         mocker,
         origin_url,
-        "completed",
-        SAVE_REQUEST_ACCEPTED,
-        SAVE_TASK_NOT_YET_SCHEDULED,
+        scheduler_task_status="completed",
+        expected_request_status=SAVE_REQUEST_ACCEPTED,
+        expected_task_status=SAVE_TASK_NOT_YET_SCHEDULED,
         visit_date=visit_date,
     )
     sors = list(
         SaveOriginRequest.objects.filter(visit_type="git", origin_url=origin_url)
     )
-    assert len(sors) == 2
+    # check_api_post_responses sends two POST requests to check YAML and JSON response
+    assert len(sors) == 3
 
     check_created_save_request_status(
         api_client,
         mocker,
         origin_url,
-        "disabled",
-        SAVE_REQUEST_ACCEPTED,
-        SAVE_TASK_NOT_YET_SCHEDULED,
+        scheduler_task_status="disabled",
+        expected_request_status=SAVE_REQUEST_ACCEPTED,
+        expected_task_status=SAVE_TASK_NOT_YET_SCHEDULED,
     )
     sors = list(
         SaveOriginRequest.objects.filter(visit_type="git", origin_url=origin_url)
     )
-    assert len(sors) == 3
+    assert len(sors) == 5
 
 
 def test_get_save_requests_unknown_origin(api_client):
@@ -317,8 +356,7 @@ def test_get_save_requests_unknown_origin(api_client):
         "api-1-save-origin",
         url_args={"visit_type": "git", "origin_url": unknown_origin_url},
     )
-    response = api_client.get(url)
-    assert response.status_code == 404
+    response = check_api_get_responses(api_client, url, status_code=404)
     assert response.data == {
         "exception": "NotFoundExc",
         "reason": (
