@@ -9,9 +9,10 @@ from django.contrib.auth.models import AnonymousUser, User
 
 from swh.web.auth.models import OIDCUser
 from swh.web.common.utils import reverse
+from swh.web.tests.utils import check_api_get_responses, check_http_get_response
 
-from .keycloak_mock import mock_keycloak
 from . import sample_data
+from .keycloak_mock import mock_keycloak
 
 
 @pytest.mark.django_db
@@ -25,11 +26,9 @@ def test_drf_django_session_auth_success(mocker, client):
     mock_keycloak(mocker)
     client.login(code="", code_verifier="", redirect_uri="")
 
-    response = client.get(url)
+    response = check_http_get_response(client, url, status_code=200)
     request = response.wsgi_request
 
-    assert response.status_code == 200
-
     # user should be authenticated
     assert isinstance(request.user, OIDCUser)
 
@@ -46,16 +45,14 @@ def test_drf_oidc_bearer_token_auth_success(mocker, api_client):
     """
     url = reverse("api-1-stat-counters")
 
-    access_token = sample_data.oidc_profile["access_token"]
+    refresh_token = sample_data.oidc_profile["refresh_token"]
 
     mock_keycloak(mocker)
-    api_client.credentials(HTTP_AUTHORIZATION=f"Bearer {access_token}")
+    api_client.credentials(HTTP_AUTHORIZATION=f"Bearer {refresh_token}")
 
-    response = api_client.get(url)
+    response = check_api_get_responses(api_client, url, status_code=200)
     request = response.wsgi_request
 
-    assert response.status_code == 200
-
     # user should be authenticated
     assert isinstance(request.user, OIDCUser)
 
@@ -68,48 +65,43 @@ def test_drf_oidc_bearer_token_auth_success(mocker, api_client):
 def test_drf_oidc_bearer_token_auth_failure(mocker, api_client):
     url = reverse("api-1-stat-counters")
 
-    access_token = sample_data.oidc_profile["access_token"]
+    refresh_token = sample_data.oidc_profile["refresh_token"]
 
     # check for failed authentication but with expected token format
     mock_keycloak(mocker, auth_success=False)
-    api_client.credentials(HTTP_AUTHORIZATION=f"Bearer {access_token}")
+    api_client.credentials(HTTP_AUTHORIZATION=f"Bearer {refresh_token}")
 
-    response = api_client.get(url)
+    response = check_api_get_responses(api_client, url, status_code=403)
     request = response.wsgi_request
 
-    assert response.status_code == 403
     assert isinstance(request.user, AnonymousUser)
 
     # check for failed authentication when token format is invalid
-    mock_keycloak(mocker)
-    api_client.credentials(HTTP_AUTHORIZATION="Bearer invalid-token-format")
+    api_client.credentials(HTTP_AUTHORIZATION="Bearer invalid-token-format-ééàà")
 
-    response = api_client.get(url)
+    response = check_api_get_responses(api_client, url, status_code=400)
     request = response.wsgi_request
 
-    assert response.status_code == 403
     assert isinstance(request.user, AnonymousUser)
 
 
 def test_drf_oidc_auth_invalid_or_missing_authorization_type(api_client):
     url = reverse("api-1-stat-counters")
 
-    access_token = sample_data.oidc_profile["access_token"]
+    refresh_token = sample_data.oidc_profile["refresh_token"]
 
     # missing authorization type
-    api_client.credentials(HTTP_AUTHORIZATION=f"{access_token}")
+    api_client.credentials(HTTP_AUTHORIZATION=f"{refresh_token}")
 
-    response = api_client.get(url)
+    response = check_api_get_responses(api_client, url, status_code=403)
     request = response.wsgi_request
 
-    assert response.status_code == 403
     assert isinstance(request.user, AnonymousUser)
 
     # invalid authorization type
     api_client.credentials(HTTP_AUTHORIZATION="Foo token")
 
-    response = api_client.get(url)
+    response = check_api_get_responses(api_client, url, status_code=403)
     request = response.wsgi_request
 
-    assert response.status_code == 403
     assert isinstance(request.user, AnonymousUser)
