@@ -8,24 +8,24 @@ import random
 from hypothesis import given
 
 from swh.web.browse.snapshot_context import (
+    _get_release,
     get_origin_visit_snapshot,
     get_snapshot_content,
     get_snapshot_context,
-    _get_release,
 )
 from swh.web.browse.utils import gen_revision_url
-from swh.web.common.identifiers import get_swh_persistent_id
+from swh.web.common.identifiers import gen_swhid
 from swh.web.common.origin_visits import get_origin_visit, get_origin_visits
 from swh.web.common.typing import (
     SnapshotBranchInfo,
-    SnapshotReleaseInfo,
     SnapshotContext,
+    SnapshotReleaseInfo,
 )
 from swh.web.common.utils import format_utc_iso_date, reverse
 from swh.web.tests.strategies import (
     origin_with_multiple_visits,
-    snapshot,
     origin_with_releases,
+    snapshot,
 )
 
 
@@ -39,12 +39,13 @@ def test_get_origin_visit_snapshot_simple(archive_data, origin):
         branches = []
         releases = []
 
-        def _process_branch_data(branch, branch_data):
+        def _process_branch_data(branch, branch_data, alias=False):
             if branch_data["target_type"] == "revision":
                 rev_data = archive_data.revision_get(branch_data["target"])
                 branches.append(
                     SnapshotBranchInfo(
                         name=branch,
+                        alias=alias,
                         revision=branch_data["target"],
                         directory=rev_data["directory"],
                         date=format_utc_iso_date(rev_data["date"]),
@@ -58,6 +59,7 @@ def test_get_origin_visit_snapshot_simple(archive_data, origin):
                 releases.append(
                     SnapshotReleaseInfo(
                         name=rel_data["name"],
+                        alias=alias,
                         branch_name=branch,
                         date=format_utc_iso_date(rel_data["date"]),
                         id=rel_data["id"],
@@ -69,11 +71,14 @@ def test_get_origin_visit_snapshot_simple(archive_data, origin):
                     )
                 )
 
+        aliases = {}
+
         for branch in sorted(snapshot["branches"].keys()):
             branch_data = snapshot["branches"][branch]
             if branch_data["target_type"] == "alias":
                 target_data = snapshot["branches"][branch_data["target"]]
-                _process_branch_data(branch, target_data)
+                aliases[branch] = target_data
+                _process_branch_data(branch, target_data, alias=True)
             else:
                 _process_branch_data(branch, branch_data)
 
@@ -83,7 +88,7 @@ def test_get_origin_visit_snapshot_simple(archive_data, origin):
             origin, visit_id=visit["visit"]
         )
 
-        assert origin_visit_branches == (branches, releases)
+        assert origin_visit_branches == (branches, releases, aliases)
 
 
 @given(snapshot())
@@ -102,7 +107,7 @@ def test_get_snapshot_context_no_origin(archive_data, snapshot):
 
         snapshot_context = get_snapshot_context(**kwargs, browse_context=browse_context)
 
-        branches, releases = get_snapshot_content(snapshot)
+        branches, releases, _ = get_snapshot_content(snapshot)
         releases = list(reversed(releases))
         revision_id = None
         root_directory = None
@@ -125,17 +130,19 @@ def test_get_snapshot_context_no_origin(archive_data, snapshot):
         branches_url = reverse("browse-snapshot-branches", url_args=url_args)
         releases_url = reverse("browse-snapshot-releases", url_args=url_args)
         is_empty = not branches and not releases
-        snapshot_swhid = get_swh_persistent_id("snapshot", snapshot)
-        snapshot_sizes = {"revision": len(branches), "release": len(releases)}
+        snapshot_swhid = gen_swhid("snapshot", snapshot)
+        snapshot_sizes = archive_data.snapshot_count_branches(snapshot)
 
         expected = SnapshotContext(
             branch="HEAD",
+            branch_alias=True,
             branches=branches,
             branches_url=branches_url,
             is_empty=is_empty,
             origin_info=None,
             origin_visits_url=None,
             release=None,
+            release_alias=False,
             release_id=None,
             query_params=query_params,
             releases=releases,
@@ -190,7 +197,7 @@ def test_get_snapshot_context_with_origin(archive_data, origin):
 
         query_params = dict(kwargs)
 
-        branches, releases = get_snapshot_content(snapshot)
+        branches, releases, _ = get_snapshot_content(snapshot)
         releases = list(reversed(releases))
         revision_id = None
         root_directory = None
@@ -216,8 +223,8 @@ def test_get_snapshot_context_with_origin(archive_data, origin):
             "browse-origin-visits", query_params={"origin_url": kwargs["origin_url"]}
         )
         is_empty = not branches and not releases
-        snapshot_swhid = get_swh_persistent_id("snapshot", snapshot)
-        snapshot_sizes = {"revision": len(branches), "release": len(releases)}
+        snapshot_swhid = gen_swhid("snapshot", snapshot)
+        snapshot_sizes = archive_data.snapshot_count_branches(snapshot)
 
         visit_info["url"] = reverse(
             "browse-origin-directory", query_params=query_params
@@ -229,12 +236,14 @@ def test_get_snapshot_context_with_origin(archive_data, origin):
 
         expected = SnapshotContext(
             branch="HEAD",
+            branch_alias=True,
             branches=branches,
             branches_url=branches_url,
             is_empty=is_empty,
             origin_info={"url": origin["url"]},
             origin_visits_url=origin_visits_url,
             release=None,
+            release_alias=False,
             release_id=None,
             query_params=query_params,
             releases=releases,
@@ -281,6 +290,7 @@ def _check_branch_release_revision_parameters(
 
     expected_branch = dict(base_expected_context)
     expected_branch["branch"] = branch["name"]
+    expected_branch["branch_alias"] = branch["alias"]
     expected_branch["revision_id"] = branch["revision"]
     expected_branch["revision_info"] = _get_revision_info(
         archive_data, branch["revision"]
@@ -303,6 +313,7 @@ def _check_branch_release_revision_parameters(
 
         expected_release = dict(base_expected_context)
         expected_release["branch"] = None
+        expected_release["branch_alias"] = False
         expected_release["release"] = release["name"]
         expected_release["release_id"] = release["id"]
         if release["target_type"] == "revision":
@@ -341,6 +352,7 @@ def _check_branch_release_revision_parameters(
     branches.append(
         SnapshotBranchInfo(
             name=revision["id"],
+            alias=False,
             revision=revision["id"],
             directory=revision["directory"],
             date=revision["date"],
@@ -351,6 +363,7 @@ def _check_branch_release_revision_parameters(
 
     expected_revision = dict(base_expected_context)
     expected_revision["branch"] = revision["id"]
+    expected_revision["branch_alias"] = False
     expected_revision["branches"] = branches
     expected_revision["revision_id"] = revision["id"]
     expected_revision["revision_info"] = _get_revision_info(
