@@ -63,6 +63,7 @@ def test_content_view_text(client, archive_data, content):
     swh_cnt_id_url = reverse("browse-swhid", url_args={"swhid": swh_cnt_id})
     assert_contains(resp, swh_cnt_id)
     assert_contains(resp, swh_cnt_id_url)
+    assert_not_contains(resp, "swh-metadata-popover")
 
 
 @given(content_text_no_highlight())
@@ -316,7 +317,9 @@ def test_content_request_errors(client, invalid_sha1, unknown_content):
     check_html_get_response(client, url, status_code=400, template_used="error.html")
 
     url = reverse("browse-content", url_args={"query_string": unknown_content["sha1"]})
-    check_html_get_response(client, url, status_code=404, template_used="error.html")
+    check_html_get_response(
+        client, url, status_code=404, template_used="browse/content.html"
+    )
 
 
 @given(content())
