@@ -3,32 +3,34 @@
 # License: GNU Affero General Public License version 3, or any later version
 # See top-level LICENSE file for more information
 
+from copy import deepcopy
 from datetime import timedelta
 import os
 import random
 import time
+from typing import Dict, List, Optional, Set
 
-from copy import deepcopy
-
+from swh.core.config import merge_configs
+from swh.indexer.ctags import CtagsIndexer
 from swh.indexer.fossology_license import FossologyLicenseIndexer
 from swh.indexer.mimetype import MimetypeIndexer
-from swh.indexer.ctags import CtagsIndexer
 from swh.indexer.storage import get_indexer_storage
-from swh.model.model import Content, OriginVisitStatus
-from swh.model.hashutil import hash_to_hex, hash_to_bytes, DEFAULT_ALGORITHMS
-from swh.model.model import Directory, Origin, OriginVisit
+from swh.indexer.storage.model import OriginIntrinsicMetadataRow
 from swh.loader.git.from_disk import GitLoaderFromArchive
+from swh.model.hashutil import DEFAULT_ALGORITHMS, hash_to_bytes, hash_to_hex
+from swh.model.model import Content, Directory, Origin, OriginVisit, OriginVisitStatus
 from swh.search import get_search
 from swh.storage.algos.dir_iterators import dir_iterator
 from swh.storage.algos.snapshot import snapshot_get_latest
+from swh.storage.interface import Sha1
 from swh.storage.utils import now
 from swh.web import config
 from swh.web.browse.utils import (
+    _re_encode_content,
     get_mimetype_and_encoding_for_content,
     prepare_content_for_display,
-    _re_encode_content,
 )
-from swh.web.common import service
+from swh.web.common import archive
 
 # Module used to initialize data that will be provided as tests input
 
@@ -68,54 +70,56 @@ def random_content():
     }
 
 
-# MimetypeIndexer with custom configuration for tests
-class _MimetypeIndexer(MimetypeIndexer):
-    def parse_config_file(self, *args, **kwargs):
-        return {
-            **_TEST_INDEXER_BASE_CONFIG,
-            "tools": {
-                "name": "file",
-                "version": "1:5.30-1+deb9u1",
-                "configuration": {"type": "library", "debian-package": "python3-magic"},
-            },
+_TEST_MIMETYPE_INDEXER_CONFIG = merge_configs(
+    _TEST_INDEXER_BASE_CONFIG,
+    {
+        "tools": {
+            "name": "file",
+            "version": "1:5.30-1+deb9u1",
+            "configuration": {"type": "library", "debian-package": "python3-magic"},
         }
+    },
+)
 
 
-# FossologyLicenseIndexer with custom configuration for tests
-class _FossologyLicenseIndexer(FossologyLicenseIndexer):
-    def parse_config_file(self, *args, **kwargs):
-        return {
-            **_TEST_INDEXER_BASE_CONFIG,
-            "workdir": "/tmp/swh/indexer.fossology.license",
-            "tools": {
-                "name": "nomos",
-                "version": "3.1.0rc2-31-ga2cbb8c",
-                "configuration": {"command_line": "nomossa <filepath>",},
+_TEST_LICENSE_INDEXER_CONFIG = merge_configs(
+    _TEST_INDEXER_BASE_CONFIG,
+    {
+        "workdir": "/tmp/swh/indexer.fossology.license",
+        "tools": {
+            "name": "nomos",
+            "version": "3.1.0rc2-31-ga2cbb8c",
+            "configuration": {"command_line": "nomossa <filepath>",},
+        },
+    },
+)
+
+
+_TEST_CTAGS_INDEXER_CONFIG = merge_configs(
+    _TEST_INDEXER_BASE_CONFIG,
+    {
+        "workdir": "/tmp/swh/indexer.ctags",
+        "languages": {"c": "c"},
+        "tools": {
+            "name": "universal-ctags",
+            "version": "~git7859817b",
+            "configuration": {
+                "command_line": """ctags --fields=+lnz --sort=no --links=no """
+                """--output-format=json <filepath>"""
             },
-        }
-
-
-# CtagsIndexer with custom configuration for tests
-class _CtagsIndexer(CtagsIndexer):
-    def parse_config_file(self, *args, **kwargs):
-        return {
-            **_TEST_INDEXER_BASE_CONFIG,
-            "workdir": "/tmp/swh/indexer.ctags",
-            "languages": {"c": "c"},
-            "tools": {
-                "name": "universal-ctags",
-                "version": "~git7859817b",
-                "configuration": {
-                    "command_line": """ctags --fields=+lnz --sort=no --links=no """
-                    """--output-format=json <filepath>"""
-                },
-            },
-        }
+        },
+    },
+)
 
 
 # Lightweight git repositories that will be loaded to generate
 # input data for tests
 _TEST_ORIGINS = [
+    {
+        "type": "git",
+        "url": "https://github.com/memononen/libtess2",
+        "archives": ["libtess2.zip"],
+    },
     {
         "type": "git",
         "url": "https://github.com/wcoder/highlightjs-line-numbers.js",
@@ -124,11 +128,6 @@ _TEST_ORIGINS = [
             "highlightjs-line-numbers.js_visit2.zip",
         ],
     },
-    {
-        "type": "git",
-        "url": "https://github.com/memononen/libtess2",
-        "archives": ["libtess2.zip"],
-    },
     {
         "type": "git",
         "url": "repo_with_submodules",
@@ -157,25 +156,44 @@ def _add_extra_contents(storage, contents):
     contents.add(pbm_content.sha1)
 
 
+INDEXER_TOOL = {
+    "tool_name": "swh-web tests",
+    "tool_version": "1.0",
+    "tool_configuration": {},
+}
+
+ORIGIN_METADATA_KEY = "vcs"
+ORIGIN_METADATA_VALUE = "git"
+
+ORIGIN_MASTER_REVISION = {}
+
+
 # Tests data initialization
 def _init_tests_data():
     # To hold reference to the memory storage
     storage = None
 
     # Create search instance
-    search = get_search("memory", {})
+    search = get_search("memory")
     search.initialize()
     search.origin_update({"url": origin["url"]} for origin in _TEST_ORIGINS)
 
+    # Create indexer storage instance that will be shared by indexers
+    idx_storage = get_indexer_storage("memory")
+
+    # Declare a test tool for origin intrinsic metadata tests
+    idx_tool = idx_storage.indexer_configuration_add([INDEXER_TOOL])[0]
+    INDEXER_TOOL["id"] = idx_tool["id"]
+
     # Load git repositories from archives
     for origin in _TEST_ORIGINS:
-        for i, archive in enumerate(origin["archives"]):
+        for i, archive_ in enumerate(origin["archives"]):
             if i > 0:
                 # ensure visit dates will be different when simulating
                 # multiple visits of an origin
                 time.sleep(1)
             origin_repo_archive = os.path.join(
-                os.path.dirname(__file__), "resources/repos/%s" % archive
+                os.path.dirname(__file__), "resources/repos/%s" % archive_
             )
             loader = GitLoaderFromArchive(
                 origin["url"],
@@ -188,7 +206,8 @@ def _init_tests_data():
                 loader.storage = storage
             loader.load()
 
-        origin.update(storage.origin_get(origin))  # add an 'id' key if enabled
+        ori = storage.origin_get([origin["url"]])[0]
+        origin.update(ori.to_dict())  # add an 'id' key if enabled
         search.origin_update([{"url": origin["url"], "has_visits": True}])
 
     for i in range(250):
@@ -208,7 +227,7 @@ def _init_tests_data():
         )
         storage.origin_visit_status_add([visit_status])
 
-    contents = set()
+    sha1s: Set[Sha1] = set()
     directories = set()
     revisions = set()
     releases = set()
@@ -224,9 +243,22 @@ def _init_tests_data():
             target_type = branch_data.target_type.value
             if target_type == "revision":
                 revisions.add(branch_data.target)
+                if b"master" in branch_name:
+                    # Add some origin intrinsic metadata for tests
+                    origin_metadata = OriginIntrinsicMetadataRow(
+                        id=origin["url"],
+                        from_revision=branch_data.target,
+                        indexer_configuration_id=idx_tool["id"],
+                        metadata={ORIGIN_METADATA_KEY: ORIGIN_METADATA_VALUE},
+                        mappings=[],
+                    )
+                    idx_storage.origin_intrinsic_metadata_add([origin_metadata])
+                    ORIGIN_MASTER_REVISION[origin["url"]] = hash_to_hex(
+                        branch_data.target
+                    )
             elif target_type == "release":
-                release = next(storage.release_get([branch_data.target]))
-                revisions.add(release["target"])
+                release = storage.release_get([branch_data.target])[0]
+                revisions.add(release.target)
                 releases.add(hash_to_hex(branch_data.target))
 
         for rev_log in storage.revision_shortlog(set(revisions)):
@@ -234,35 +266,41 @@ def _init_tests_data():
             revisions.add(rev_id)
 
         for rev in storage.revision_get(revisions):
-            dir_id = rev["directory"]
+            if rev is None:
+                continue
+            dir_id = rev.directory
             directories.add(hash_to_hex(dir_id))
             for entry in dir_iterator(storage, dir_id):
                 if entry["type"] == "file":
-                    contents.add(entry["sha1"])
+                    sha1s.add(entry["sha1"])
                     content_path[entry["sha1"]] = "/".join(
                         [hash_to_hex(dir_id), entry["path"].decode("utf-8")]
                     )
                 elif entry["type"] == "dir":
                     directories.add(hash_to_hex(entry["target"]))
 
-    _add_extra_contents(storage, contents)
+    _add_extra_contents(storage, sha1s)
 
     # Get all checksums for each content
-    result = storage.content_get_metadata(contents)
-    contents = []
-    for sha1, contents_metadata in result.items():
-        sha1 = contents_metadata[0]["sha1"]
+    result: List[Optional[Content]] = storage.content_get(list(sha1s))
+
+    contents: List[Dict] = []
+    for content in result:
+        assert content is not None
+        sha1 = hash_to_hex(content.sha1)
         content_metadata = {
-            algo: hash_to_hex(contents_metadata[0][algo]) for algo in DEFAULT_ALGORITHMS
+            algo: hash_to_hex(getattr(content, algo)) for algo in DEFAULT_ALGORITHMS
         }
 
         path = ""
-        if sha1 in content_path:
-            path = content_path[sha1]
-        cnt = next(storage.content_get([sha1]))
-        mimetype, encoding = get_mimetype_and_encoding_for_content(cnt["data"])
-        _, _, cnt["data"] = _re_encode_content(mimetype, encoding, cnt["data"])
-        content_display_data = prepare_content_for_display(cnt["data"], mimetype, path)
+        if content.sha1 in content_path:
+            path = content_path[content.sha1]
+
+        cnt_data = storage.content_get_data(content.sha1)
+        assert cnt_data is not None
+        mimetype, encoding = get_mimetype_and_encoding_for_content(cnt_data)
+        _, _, cnt_data = _re_encode_content(mimetype, encoding, cnt_data)
+        content_display_data = prepare_content_for_display(cnt_data, mimetype, path)
 
         content_metadata.update(
             {
@@ -273,15 +311,15 @@ def _init_tests_data():
                 "data": content_display_data["content_data"],
             }
         )
-        _contents[hash_to_hex(sha1)] = content_metadata
+        _contents[sha1] = content_metadata
         contents.append(content_metadata)
 
-    # Create indexer storage instance that will be shared by indexers
-    idx_storage = get_indexer_storage("memory", {})
-
     # Add the empty directory to the test archive
     storage.directory_add([Directory(entries=())])
 
+    # Add empty content to the test archive
+    storage.content_add([Content.from_data(data=b"")])
+
     # Return tests data
     return {
         "search": search,
@@ -301,12 +339,12 @@ def _init_indexers(tests_data):
     # Instantiate content indexers that will be used in tests
     # and force them to use the memory storages
     indexers = {}
-    for idx_name, idx_class in (
-        ("mimetype_indexer", _MimetypeIndexer),
-        ("license_indexer", _FossologyLicenseIndexer),
-        ("ctags_indexer", _CtagsIndexer),
+    for idx_name, idx_class, idx_config in (
+        ("mimetype_indexer", MimetypeIndexer, _TEST_MIMETYPE_INDEXER_CONFIG),
+        ("license_indexer", FossologyLicenseIndexer, _TEST_LICENSE_INDEXER_CONFIG),
+        ("ctags_indexer", CtagsIndexer, _TEST_CTAGS_INDEXER_CONFIG),
     ):
-        idx = idx_class()
+        idx = idx_class(config=idx_config)
         idx.storage = tests_data["storage"]
         idx.objstorage = tests_data["storage"].objstorage
         idx.idx_storage = tests_data["idx_storage"]
@@ -357,6 +395,6 @@ def override_storages(storage, idx_storage, search):
         {"storage": storage, "indexer_storage": idx_storage, "search": search,}
     )
 
-    service.storage = storage
-    service.idx_storage = idx_storage
-    service.search = search
+    archive.storage = storage
+    archive.idx_storage = idx_storage
+    archive.search = search
